@@ -51,7 +51,7 @@ Text::ANSITable::StyleSet::AltRow
 
 =head1 VERSION
 
-This document describes version 0.34 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2014-07-10.
+This document describes version 0.35 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2014-12-05.
 
 =for Pod::Coverage ^(summary|apply)$
 
@@ -71,7 +71,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSIT
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Text-ANSITable>.
+Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
 
 =head1 BUGS
 
@@ -83,11 +83,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
